@@ -10,7 +10,6 @@
 //! when parsing command-line options (e.g. "-foo -o -bar -baz" is equivalent
 //! to "-foo -o ( -bar -baz )", not "( -foo -o -bar ) -baz").
 use std::error::Error;
-use std::iter::Iterator;
 use std::path::Path;
 use walkdir::DirEntry;
 
@@ -48,7 +47,9 @@ impl Matcher for AndMatcher {
     }
 
     fn has_side_effects(&self) -> bool {
-        self.submatchers.iter().any(|x| x.has_side_effects())
+        self.submatchers
+            .iter()
+            .any(super::Matcher::has_side_effects)
     }
 
     fn finished_dir(&self, dir: &Path) {
@@ -122,7 +123,9 @@ impl Matcher for OrMatcher {
     }
 
     fn has_side_effects(&self) -> bool {
-        self.submatchers.iter().any(|x| x.has_side_effects())
+        self.submatchers
+            .iter()
+            .any(super::Matcher::has_side_effects)
     }
 
     fn finished_dir(&self, dir: &Path) {
@@ -155,8 +158,7 @@ impl OrMatcherBuilder {
         if self.submatchers.last().unwrap().submatchers.is_empty() {
             return Err(From::from(format!(
                 "invalid expression; you have used a binary operator \
-                 '{}' with nothing before it.",
-                arg
+                 '{arg}' with nothing before it."
             )));
         }
         self.submatchers.push(AndMatcherBuilder::new());
@@ -216,7 +218,9 @@ impl Matcher for ListMatcher {
     }
 
     fn has_side_effects(&self) -> bool {
-        self.submatchers.iter().any(|x| x.has_side_effects())
+        self.submatchers
+            .iter()
+            .any(super::Matcher::has_side_effects)
     }
 
     fn finished_dir(&self, dir: &Path) {
@@ -358,11 +362,9 @@ mod tests {
     use super::*;
     use crate::find::matchers::quit::QuitMatcher;
     use crate::find::matchers::tests::get_dir_entry_for;
-    use crate::find::matchers::{Matcher, MatcherIO};
     use crate::find::tests::FakeDependencies;
     use std::cell::RefCell;
     use std::rc::Rc;
-    use walkdir::DirEntry;
 
     /// Simple Matcher impl that has side effects
     pub struct HasSideEffects;
