@@ -8,7 +8,9 @@ mod access;
 mod delete;
 mod empty;
 pub mod exec;
+pub mod fs;
 mod glob;
+mod group;
 mod lname;
 mod logical_matchers;
 mod name;
@@ -19,12 +21,17 @@ mod printf;
 mod prune;
 mod quit;
 mod regex;
+mod samefile;
 mod size;
+#[cfg(unix)]
 mod stat;
 mod time;
 mod type_matcher;
+mod user;
 
 use ::regex::Regex;
+use chrono::{DateTime, Datelike, NaiveDateTime, Utc};
+use fs::FileSystemMatcher;
 use std::path::Path;
 use std::time::SystemTime;
 use std::{error::Error, str::FromStr};
@@ -34,6 +41,7 @@ use self::access::AccessMatcher;
 use self::delete::DeleteMatcher;
 use self::empty::EmptyMatcher;
 use self::exec::SingleExecMatcher;
+use self::group::{GroupMatcher, NoGroupMatcher};
 use self::lname::LinkNameMatcher;
 use self::logical_matchers::{
     AndMatcherBuilder, FalseMatcher, ListMatcherBuilder, NotMatcher, TrueMatcher,
@@ -46,10 +54,16 @@ use self::printf::Printf;
 use self::prune::PruneMatcher;
 use self::quit::QuitMatcher;
 use self::regex::RegexMatcher;
+use self::samefile::SameFileMatcher;
 use self::size::SizeMatcher;
+#[cfg(unix)]
 use self::stat::{InodeMatcher, LinksMatcher};
-use self::time::{FileTimeMatcher, FileTimeType, NewerMatcher};
+use self::time::{
+    FileAgeRangeMatcher, FileTimeMatcher, FileTimeType, NewerMatcher, NewerOptionMatcher,
+    NewerOptionType, NewerTimeMatcher,
+};
 use self::type_matcher::TypeMatcher;
+use self::user::{NoUserMatcher, UserMatcher};
 
 use super::{Config, Dependencies};
 
@@ -74,6 +88,7 @@ impl<'a> MatcherIO<'a> {
         self.should_skip_dir = true;
     }
 
+    #[must_use]
     pub fn should_skip_current_dir(&self) -> bool {
         self.should_skip_dir
     }
@@ -82,10 +97,12 @@ impl<'a> MatcherIO<'a> {
         self.quit = true;
     }
 
+    #[must_use]
     pub fn should_quit(&self) -> bool {
         self.quit
     }
 
+    #[must_use]
     pub fn now(&self) -> SystemTime {
         self.deps.now()
     }
@@ -140,11 +157,11 @@ impl Matcher for Box<dyn Matcher> {
     }
 
     fn finished_dir(&self, finished_directory: &Path) {
-        (**self).finished_dir(finished_directory)
+        (**self).finished_dir(finished_directory);
     }
 
     fn finished(&self) {
-        (**self).finished()
+        (**self).finished();
     }
 }
 
@@ -203,9 +220,8 @@ fn convert_arg_to_number(
     match value_as_string.parse::<usize>() {
         Ok(val) => Ok(val),
         _ => Err(From::from(format!(
-            "Expected a positive decimal integer argument to {}, but got \
-             `{}'",
-            option_name, value_as_string
+            "Expected a positive decimal integer argument to {option_name}, but got \
+             `{value_as_string}'"
         ))),
     }
 }
@@ -214,7 +230,7 @@ fn convert_arg_to_comparable_value(
     option_name: &str,
     value_as_string: &str,
 ) -> Result<ComparableValue, Box<dyn Error>> {
-    let re = Regex::new(r"([+-]?)(\d+)$")?;
+    let re = Regex::new(r"^([+-]?)(\d+)$")?;
     if let Some(groups) = re.captures(value_as_string) {
         if let Ok(val) = groups[2].parse::<u64>() {
             return Ok(match &groups[1] {
@@ -226,8 +242,7 @@ fn convert_arg_to_comparable_value(
     }
     Err(From::from(format!(
         "Expected a decimal integer (with optional + or - prefix) argument \
-         to {}, but got `{}'",
-        option_name, value_as_string
+         to {option_name}, but got `{value_as_string}'"
     )))
 }
 
@@ -250,11 +265,80 @@ fn convert_arg_to_comparable_value_and_suffix(
     }
     Err(From::from(format!(
         "Expected a decimal integer (with optional + or - prefix) and \
-         (optional suffix) argument to {}, but got `{}'",
-        option_name, value_as_string
+         (optional suffix) argument to {option_name}, but got `{value_as_string}'"
     )))
 }
 
+/// This is a function that converts a specific string format into a timestamp.
+/// It allows converting a time string of
+/// "(week abbreviation) (date), (year) (time)" to a Unix timestamp.
+/// such as: "jan 01, 2025 00:00:01" -> 1735689601000
+/// When (time) is not provided, it will be automatically filled in as 00:00:00
+/// such as: "jan 01, 2025" = "jan 01, 2025 00:00:00" -> 1735689600000
+fn parse_date_str_to_timestamps(date_str: &str) -> Option<i64> {
+    let regex_pattern =
+        r"^(?P<month_day>\w{3} \d{2})?(?:, (?P<year>\d{4}))?(?: (?P<time>\d{2}:\d{2}:\d{2}))?$";
+    let re = Regex::new(regex_pattern);
+
+    if let Some(captures) = re.ok()?.captures(date_str) {
+        let now = Utc::now();
+        let month_day = captures
+            .get(1)
+            .map_or(format!("{} {}", now.format("%b"), now.format("%d")), |m| {
+                m.as_str().to_string()
+            });
+        // If no year input.
+        let year = captures
+            .get(2)
+            .map_or(now.year(), |m| m.as_str().parse().unwrap());
+        // If the user does not enter a specific time, it will be filled with 0
+        let time_str = captures.get(3).map_or("00:00:00", |m| m.as_str());
+        let date_time_str = format!("{month_day}, {year} {time_str}");
+        let datetime = NaiveDateTime::parse_from_str(&date_time_str, "%b %d, %Y %H:%M:%S").ok()?;
+        let utc_datetime = DateTime::<Utc>::from_naive_utc_and_offset(datetime, Utc);
+        Some(utc_datetime.timestamp_millis())
+    } else {
+        None
+    }
+}
+
+/// This function implements the function of matching substrings of
+/// X and Y from the -newerXY string.
+/// X and Y are constrained to a/B/c/m and t.
+/// such as: "-neweraB" -> Some(a, B) "-neweraD" -> None
+///
+/// Additionally, there is support for the -anewer and -cnewer short arguments. as follows:
+/// 1. -anewer is equivalent to -neweram
+/// 2. -cnewer is equivalent to - newercm
+///
+/// If -newer is used it will be resolved to -newermm.
+fn parse_str_to_newer_args(input: &str) -> Option<(String, String)> {
+    if input.is_empty() {
+        return None;
+    }
+
+    if input == "-newer" {
+        return Some(("m".to_string(), "m".to_string()));
+    }
+
+    if input == "-anewer" {
+        return Some(("a".to_string(), "m".to_string()));
+    }
+
+    if input == "-cnewer" {
+        return Some(("c".to_string(), "m".to_string()));
+    }
+
+    let re = Regex::new(r"-newer([aBcm])([aBcmt])").unwrap();
+    if let Some(captures) = re.captures(input) {
+        let x = captures.get(1)?.as_str().to_string();
+        let y = captures.get(2)?.as_str().to_string();
+        Some((x, y))
+    } else {
+        None
+    }
+}
+
 /// The main "translate command-line args into a matcher" function. Will call
 /// itself recursively if it encounters an opening bracket. A successful return
 /// consists of a tuple containing the new index into the args array to use (if
@@ -339,6 +423,13 @@ fn build_matcher_tree(
                 i += 1;
                 Some(TypeMatcher::new(args[i])?.into_box())
             }
+            "-fstype" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+                i += 1;
+                Some(FileSystemMatcher::new(args[i].to_string()).into_box())
+            }
             "-delete" => {
                 // -delete implicitly requires -depth
                 config.depth_first = true;
@@ -367,6 +458,20 @@ fn build_matcher_tree(
                 i += 1;
                 Some(FileTimeMatcher::new(file_time_type, days).into_box())
             }
+            "-amin" | "-cmin" | "-mmin" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+                let file_time_type = match args[i] {
+                    "-amin" => FileTimeType::Accessed,
+                    "-cmin" => FileTimeType::Created,
+                    "-mmin" => FileTimeType::Modified,
+                    _ => unreachable!("Encountered unexpected value {}", args[i]),
+                };
+                let minutes = convert_arg_to_comparable_value(args[i], args[i + 1])?;
+                i += 1;
+                Some(FileAgeRangeMatcher::new(file_time_type, minutes).into_box())
+            }
             "-size" => {
                 if i >= args.len() - 1 {
                     return Err(From::from(format!("missing argument to {}", args[i])));
@@ -403,21 +508,119 @@ fn build_matcher_tree(
                         .into_box(),
                 )
             }
+            #[cfg(unix)]
             "-inum" => {
                 if i >= args.len() - 1 {
                     return Err(From::from(format!("missing argument to {}", args[i])));
                 }
                 let inum = convert_arg_to_comparable_value(args[i], args[i + 1])?;
                 i += 1;
-                Some(InodeMatcher::new(inum)?.into_box())
+                Some(InodeMatcher::new(inum).into_box())
             }
+            #[cfg(not(unix))]
+            "-inum" => {
+                return Err(From::from(
+                    "Inode numbers are not available on this platform",
+                ));
+            }
+            #[cfg(unix)]
             "-links" => {
                 if i >= args.len() - 1 {
                     return Err(From::from(format!("missing argument to {}", args[i])));
                 }
                 let inum = convert_arg_to_comparable_value(args[i], args[i + 1])?;
                 i += 1;
-                Some(LinksMatcher::new(inum)?.into_box())
+                Some(LinksMatcher::new(inum).into_box())
+            }
+            #[cfg(not(unix))]
+            "-links" => {
+                return Err(From::from("Link counts are not available on this platform"));
+            }
+            "-samefile" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+                i += 1;
+                let path = args[i];
+                let matcher = SameFileMatcher::new(path).map_err(|e| format!("{path}: {e}"))?;
+                Some(matcher.into_box())
+            }
+            "-user" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+
+                let user = args[i + 1];
+
+                if user.is_empty() {
+                    return Err(From::from("The argument to -user should not be empty"));
+                }
+
+                i += 1;
+                let matcher = UserMatcher::from_user_name(user);
+                match matcher.uid() {
+                    Some(_) => Some(matcher.into_box()),
+                    None => {
+                        return Err(From::from(format!(
+                            "{} is not the name of a known user",
+                            user
+                        )))
+                    }
+                }
+            }
+            "-nouser" => Some(NoUserMatcher {}.into_box()),
+            "-uid" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+                // check if the argument is a number
+                let uid = args[i + 1].parse::<u32>();
+                if uid.is_err() {
+                    return Err(From::from(format!("{} is not a number", args[i + 1])));
+                }
+                i += 1;
+                Some(UserMatcher::from_uid(uid.unwrap()).into_box())
+            }
+            "-group" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+
+                let group = args[i + 1];
+
+                if group.is_empty() {
+                    return Err(From::from(
+                        "Argument to -group is empty, but should be a group name",
+                    ));
+                }
+
+                i += 1;
+                let matcher = GroupMatcher::from_group_name(group);
+                match matcher.gid() {
+                    Some(_) => Some(matcher.into_box()),
+                    None => {
+                        return Err(From::from(format!(
+                            "{} is not the name of an existing group",
+                            group
+                        )))
+                    }
+                }
+            }
+            "-nogroup" => Some(NoGroupMatcher {}.into_box()),
+            "-gid" => {
+                if i >= args.len() - 1 {
+                    return Err(From::from(format!("missing argument to {}", args[i])));
+                }
+                // check if the argument is a number
+                let gid = args[i + 1].parse::<u32>();
+                if gid.is_err() {
+                    return Err(From::from(format!(
+                        "find: invalid argument `{}' to `-gid'",
+                        args[i + 1]
+                    )));
+                }
+                i += 1;
+                Some(GroupMatcher::from_gid(gid.unwrap()).into_box())
             }
             "-executable" => Some(AccessMatcher::Executable.into_box()),
             "-perm" => {
@@ -479,6 +682,14 @@ fn build_matcher_tree(
                 if !expecting_bracket {
                     return Err(From::from("you have too many ')'"));
                 }
+
+                let bracket = args[i - 1];
+                if bracket == "(" {
+                    return Err(From::from(
+                        "invalid expression; empty parentheses are not allowed.",
+                    ));
+                }
+
                 return Ok((i, top_level_matcher.build()));
             }
             "-d" | "-depth" => {
@@ -521,7 +732,40 @@ fn build_matcher_tree(
                 None
             }
 
-            _ => return Err(From::from(format!("Unrecognized flag: '{}'", args[i]))),
+            _ => {
+                match parse_str_to_newer_args(args[i]) {
+                    Some((x_option, y_option)) => {
+                        if i >= args.len() - 1 {
+                            return Err(From::from(format!("missing argument to {}", args[i])));
+                        }
+                        #[cfg(target_os = "linux")]
+                        if x_option == "B" {
+                            return Err(From::from("find: This system does not provide a way to find the birth time of a file."));
+                        }
+                        if y_option == "t" {
+                            let time = args[i + 1];
+                            let newer_time_type = NewerOptionType::from_str(x_option.as_str());
+                            // Convert args to unix timestamps. (expressed in numeric types)
+                            let comparable_time = match parse_date_str_to_timestamps(time) {
+                                Some(timestamp) => timestamp,
+                                None => {
+                                    return Err(From::from(format!(
+                                        "find: I cannot figure out how to interpret ‘{}’ as a date or time",
+                                        args[i + 1]
+                                    )))
+                                }
+                            };
+                            i += 1;
+                            Some(NewerTimeMatcher::new(newer_time_type, comparable_time).into_box())
+                        } else {
+                            let file_path = args[i + 1];
+                            i += 1;
+                            Some(NewerOptionMatcher::new(x_option, y_option, file_path)?.into_box())
+                        }
+                    }
+                    None => return Err(From::from(format!("Unrecognized flag: '{}'", args[i]))),
+                }
+            }
         };
         if let Some(submatcher) = possible_submatcher {
             if invert_next_matcher {
@@ -547,11 +791,10 @@ mod tests {
     use super::*;
     use crate::find::tests::fix_up_slashes;
     use crate::find::tests::FakeDependencies;
-    use crate::find::Config;
-    use walkdir::{DirEntry, WalkDir};
+    use walkdir::WalkDir;
 
-    /// Helper function for tests to get a DirEntry object. directory should
-    /// probably be a string starting with "test_data/" (cargo's tests run with
+    /// Helper function for tests to get a `DirEntry` object. directory should
+    /// probably be a string starting with `test_data/` (cargo's tests run with
     /// a working directory set to the root findutils folder).
     pub fn get_dir_entry_for(directory: &str, filename: &str) -> DirEntry {
         for wrapped_dir_entry in WalkDir::new(fix_up_slashes(directory)) {
@@ -566,7 +809,7 @@ mod tests {
                 return dir_entry;
             }
         }
-        panic!("Couldn't find {} in {}", filename, directory);
+        panic!("Couldn't find {filename} in {directory}");
     }
 
     #[test]
@@ -857,7 +1100,10 @@ mod tests {
     fn build_top_level_matcher_too_many_brackets() {
         let mut config = Config::default();
 
-        if let Err(e) = build_top_level_matcher(&["-true", "(", ")", ")"], &mut config) {
+        if let Err(e) = build_top_level_matcher(
+            &["-type", "f", "(", "-name", "*.txt", ")", ")"],
+            &mut config,
+        ) {
             assert!(e.to_string().contains("too many ')'"));
         } else {
             panic!("parsing argument list with too many closing brackets should fail");
@@ -913,6 +1159,17 @@ mod tests {
         }
     }
 
+    #[test]
+    fn build_top_level_matcher_expression_empty_parentheses() {
+        let mut config = Config::default();
+
+        if let Err(e) = build_top_level_matcher(&["-true", "(", ")"], &mut config) {
+            assert!(e.to_string().contains("empty parentheses are not allowed"));
+        } else {
+            panic!("parsing argument list with empty parentheses in an expression should fail");
+        }
+    }
+
     #[test]
     fn comparable_value_matches() {
         assert!(
@@ -920,15 +1177,15 @@ mod tests {
             "0 should not be less than 0"
         );
         assert!(
-            ComparableValue::LessThan(u64::max_value()).matches(0),
+            ComparableValue::LessThan(u64::MAX).matches(0),
             "0 should be less than max_value"
         );
         assert!(
-            !ComparableValue::LessThan(0).matches(u64::max_value()),
+            !ComparableValue::LessThan(0).matches(u64::MAX),
             "max_value should not be less than 0"
         );
         assert!(
-            !ComparableValue::LessThan(u64::max_value()).matches(u64::max_value()),
+            !ComparableValue::LessThan(u64::MAX).matches(u64::MAX),
             "max_value should not be less than max_value"
         );
 
@@ -937,15 +1194,15 @@ mod tests {
             "0 should be equal to 0"
         );
         assert!(
-            !ComparableValue::EqualTo(u64::max_value()).matches(0),
+            !ComparableValue::EqualTo(u64::MAX).matches(0),
             "0 should not be equal to max_value"
         );
         assert!(
-            !ComparableValue::EqualTo(0).matches(u64::max_value()),
+            !ComparableValue::EqualTo(0).matches(u64::MAX),
             "max_value should not be equal to 0"
         );
         assert!(
-            ComparableValue::EqualTo(u64::max_value()).matches(u64::max_value()),
+            ComparableValue::EqualTo(u64::MAX).matches(u64::MAX),
             "max_value should be equal to max_value"
         );
 
@@ -954,15 +1211,15 @@ mod tests {
             "0 should not be more than 0"
         );
         assert!(
-            !ComparableValue::MoreThan(u64::max_value()).matches(0),
+            !ComparableValue::MoreThan(u64::MAX).matches(0),
             "0 should not be more than max_value"
         );
         assert!(
-            ComparableValue::MoreThan(0).matches(u64::max_value()),
+            ComparableValue::MoreThan(0).matches(u64::MAX),
             "max_value should be more than 0"
         );
         assert!(
-            !ComparableValue::MoreThan(u64::max_value()).matches(u64::max_value()),
+            !ComparableValue::MoreThan(u64::MAX).matches(u64::MAX),
             "max_value should not be more than max_value"
         );
     }
@@ -974,23 +1231,23 @@ mod tests {
             "0 should not be less than 0"
         );
         assert!(
-            ComparableValue::LessThan(u64::max_value()).imatches(0),
+            ComparableValue::LessThan(u64::MAX).imatches(0),
             "0 should be less than max_value"
         );
         assert!(
-            !ComparableValue::LessThan(0).imatches(i64::max_value()),
+            !ComparableValue::LessThan(0).imatches(i64::MAX),
             "max_value should not be less than 0"
         );
         assert!(
-            ComparableValue::LessThan(u64::max_value()).imatches(i64::max_value()),
+            ComparableValue::LessThan(u64::MAX).imatches(i64::MAX),
             "max_value should be less than max_value"
         );
         assert!(
-            ComparableValue::LessThan(0).imatches(i64::min_value()),
+            ComparableValue::LessThan(0).imatches(i64::MIN),
             "min_value should be less than 0"
         );
         assert!(
-            ComparableValue::LessThan(u64::max_value()).imatches(i64::min_value()),
+            ComparableValue::LessThan(u64::MAX).imatches(i64::MIN),
             "min_value should be less than max_value"
         );
 
@@ -999,27 +1256,27 @@ mod tests {
             "0 should be equal to 0"
         );
         assert!(
-            !ComparableValue::EqualTo(u64::max_value()).imatches(0),
+            !ComparableValue::EqualTo(u64::MAX).imatches(0),
             "0 should not be equal to max_value"
         );
         assert!(
-            !ComparableValue::EqualTo(0).imatches(i64::max_value()),
+            !ComparableValue::EqualTo(0).imatches(i64::MAX),
             "max_value should not be equal to 0"
         );
         assert!(
-            !ComparableValue::EqualTo(u64::max_value()).imatches(i64::max_value()),
+            !ComparableValue::EqualTo(u64::MAX).imatches(i64::MAX),
             "max_value should not be equal to i64::max_value"
         );
         assert!(
-            ComparableValue::EqualTo(i64::max_value() as u64).imatches(i64::max_value()),
+            ComparableValue::EqualTo(i64::MAX as u64).imatches(i64::MAX),
             "i64::max_value should be equal to i64::max_value"
         );
         assert!(
-            !ComparableValue::EqualTo(0).imatches(i64::min_value()),
+            !ComparableValue::EqualTo(0).imatches(i64::MIN),
             "min_value should not be equal to 0"
         );
         assert!(
-            !ComparableValue::EqualTo(u64::max_value()).imatches(i64::min_value()),
+            !ComparableValue::EqualTo(u64::MAX).imatches(i64::MIN),
             "min_value should not be equal to max_value"
         );
 
@@ -1028,23 +1285,23 @@ mod tests {
             "0 should not be more than 0"
         );
         assert!(
-            !ComparableValue::MoreThan(u64::max_value()).imatches(0),
+            !ComparableValue::MoreThan(u64::MAX).imatches(0),
             "0 should not be more than max_value"
         );
         assert!(
-            ComparableValue::MoreThan(0).imatches(i64::max_value()),
+            ComparableValue::MoreThan(0).imatches(i64::MAX),
             "max_value should be more than 0"
         );
         assert!(
-            !ComparableValue::MoreThan(u64::max_value()).imatches(i64::max_value()),
+            !ComparableValue::MoreThan(u64::MAX).imatches(i64::MAX),
             "max_value should not be more than max_value"
         );
         assert!(
-            !ComparableValue::MoreThan(0).imatches(i64::min_value()),
+            !ComparableValue::MoreThan(0).imatches(i64::MIN),
             "min_value should not be more than 0"
         );
         assert!(
-            !ComparableValue::MoreThan(u64::max_value()).imatches(i64::min_value()),
+            !ComparableValue::MoreThan(u64::MAX).imatches(i64::MIN),
             "min_value should not be more than max_value"
         );
     }
@@ -1056,8 +1313,7 @@ mod tests {
         if let Err(e) = build_top_level_matcher(&["-ctime", "-123."], &mut config) {
             assert!(
                 e.to_string().contains("Expected a decimal integer"),
-                "bad description: {}",
-                e
+                "bad description: {e}"
             );
         } else {
             panic!("parsing a bad ctime value should fail");
@@ -1154,4 +1410,71 @@ mod tests {
             panic!("-perm with no mode pattern should fail");
         }
     }
+
+    #[test]
+    fn convert_exception_arg_to_comparable_value_test() {
+        let exception_args = ["1%2", "1%2%3", "1a2", "1%2a", "abc", "-", "+", "%"];
+
+        for arg in exception_args {
+            let comparable = convert_arg_to_comparable_value("test", arg);
+            assert!(
+                comparable.is_err(),
+                "{} should be parse to Comparable correctly",
+                arg
+            );
+        }
+    }
+
+    #[test]
+    fn parse_date_str_to_timestamps_test() {
+        let full_date_timestamps = parse_date_str_to_timestamps("jan 01, 2025 00:00:01").unwrap();
+        assert!(full_date_timestamps.to_string().contains("1735689601000"));
+
+        let not_include_time_date_timestamps =
+            parse_date_str_to_timestamps("jan 01, 2025").unwrap();
+        assert!(not_include_time_date_timestamps
+            .to_string()
+            .contains("1735689600000"));
+
+        // pass if return current time.
+        let none_date_timestamps = parse_date_str_to_timestamps("");
+        let now_but_zero_hour_min_sec = Utc::now()
+            .date_naive()
+            .and_hms_opt(0, 0, 0)
+            .unwrap()
+            .and_utc()
+            .timestamp_millis();
+        assert_eq!(none_date_timestamps, Some(now_but_zero_hour_min_sec));
+    }
+
+    #[test]
+    fn parse_str_to_newer_args_test() {
+        // test for error case
+        let arg = parse_str_to_newer_args("");
+        assert!(arg.is_none());
+
+        // test for short options
+        // -newer equivalent to -newermm
+        let arg = parse_str_to_newer_args("-newer").unwrap();
+        assert_eq!(("m".to_string(), "m".to_string()), arg);
+
+        // -anewer equivalent to -neweram
+        let arg = parse_str_to_newer_args("-anewer").unwrap();
+        assert_eq!(("a".to_string(), "m".to_string()), arg);
+
+        // -cnewer equivalent to - newercm
+        let arg = parse_str_to_newer_args("-cnewer").unwrap();
+        assert_eq!(("c".to_string(), "m".to_string()), arg);
+
+        let x_options = ["a", "B", "c", "m"];
+        let y_options = ["a", "B", "c", "m", "t"];
+
+        for &x in x_options.iter() {
+            for &y in &y_options {
+                let eq: (String, String) = (String::from(x), String::from(y));
+                let arg = parse_str_to_newer_args(&format!("-newer{x}{y}").to_string()).unwrap();
+                assert_eq!(eq, arg);
+            }
+        }
+    }
 }
