@@ -41,7 +41,7 @@ impl ComparisonType {
 
 #[cfg(unix)]
 mod parsing {
-    use super::*;
+    use super::{parse_numeric, parse_symbolic, ComparisonType, Error};
 
     pub fn split_comparison_type(pattern: &str) -> (ComparisonType, &str) {
         let mut chars = pattern.chars();
@@ -144,7 +144,6 @@ mod tests {
     use super::*;
 
     use crate::find::matchers::tests::get_dir_entry_for;
-    use crate::find::matchers::Matcher;
     use crate::find::tests::FakeDependencies;
 
     #[track_caller]
