@@ -158,15 +158,14 @@ impl FormatStringParser<'_> {
         // Try parsing an octal sequence first.
         let first = self.front()?;
         if first.is_digit(OCTAL_RADIX) {
-            if let Ok(code) = self
-                .peek(OCTAL_LEN)
-                .and_then(|octal| u32::from_str_radix(octal, OCTAL_RADIX).map_err(|e| e.into()))
-            {
+            if let Ok(code) = self.peek(OCTAL_LEN).and_then(|octal| {
+                u32::from_str_radix(octal, OCTAL_RADIX).map_err(std::convert::Into::into)
+            }) {
                 // safe to unwrap: .peek() already succeeded above.
                 let octal = self.advance_by(OCTAL_LEN).unwrap();
                 return match char::from_u32(code) {
                     Some(c) => Ok(FormatComponent::Literal(c.to_string())),
-                    None => Err(format!("Invalid character value: \\{}", octal).into()),
+                    None => Err(format!("Invalid character value: \\{octal}").into()),
                 };
             }
         }
@@ -186,7 +185,7 @@ impl FormatStringParser<'_> {
                 'v' => "\x0B",
                 '0' => "\0",
                 '\\' => "\\",
-                c => return Err(format!("Invalid escape sequence: \\{}", c).into()),
+                c => return Err(format!("Invalid escape sequence: \\{c}").into()),
             };
 
             Ok(FormatComponent::Literal(c.to_string()))
@@ -220,10 +219,10 @@ impl FormatStringParser<'_> {
                 // We can't store the parsed items inside TimeFormat, because the items
                 // take a reference to the full format string, but we still try to parse
                 // it here so that errors get caught early.
-                let format = format!("%{}", c);
+                let format = format!("%{c}");
                 match StrftimeItems::new(&format).next() {
                     None | Some(chrono::format::Item::Error) => {
-                        Err(format!("Invalid time specifier: %{}{}", first, c).into())
+                        Err(format!("Invalid time specifier: %{first}{c}").into())
                     }
                     Some(_item) => Ok(TimeFormat::Strftime(format)),
                 }
@@ -318,7 +317,7 @@ impl FormatStringParser<'_> {
             let component = match self.advance_one().unwrap() {
                 '\\' => self.parse_escape_sequence()?,
                 '%' => self.parse_format_specifier()?,
-                _ => panic!("Stopped at unexpected character: {}", self.string),
+                _ => panic!("{}", "Stopped at unexpected character: {self.string}"),
             };
             components.push(component);
         }
@@ -388,7 +387,7 @@ fn format_directive<'entry>(
                 // symlink itself instead.
                 file_info.path().symlink_metadata()
             } else {
-                file_info.metadata().map_err(|e| e.into())
+                file_info.metadata().map_err(std::convert::Into::into)
             }
         })
     };
@@ -468,8 +467,7 @@ fn format_directive<'entry>(
             fs_list
                 .into_iter()
                 .find(|fs| fs.dev_id == dev_id)
-                .map(|fs| fs.fs_type)
-                .unwrap_or_else(String::new)
+                .map_or_else(String::new, |fs| fs.fs_type)
                 .into()
         }
 
@@ -620,7 +618,7 @@ impl Matcher for Printf {
 
         for component in &self.format.components {
             match component {
-                FormatComponent::Literal(literal) => write!(out, "{}", literal).unwrap(),
+                FormatComponent::Literal(literal) => write!(out, "{literal}").unwrap(),
                 FormatComponent::Flush => out.flush().unwrap(),
                 FormatComponent::Directive {
                     directive,
@@ -631,14 +629,14 @@ impl Matcher for Printf {
                         if let Some(width) = width {
                             match justify {
                                 Justify::Left => {
-                                    write!(out, "{:<width$}", content, width = width).unwrap();
+                                    write!(out, "{content:<width$}").unwrap();
                                 }
                                 Justify::Right => {
-                                    write!(out, "{:>width$}", content, width = width).unwrap();
+                                    write!(out, "{content:>width$}").unwrap();
                                 }
                             }
                         } else {
-                            write!(out, "{}", content).unwrap();
+                            write!(out, "{content}").unwrap();
                         }
                     }
                     Err(e) => {
@@ -666,12 +664,11 @@ mod tests {
     use std::fs::File;
     use std::io::ErrorKind;
 
-    use chrono::TimeZone;
+    use chrono::{Duration, TimeZone};
     use tempfile::Builder;
 
     use super::*;
     use crate::find::matchers::tests::get_dir_entry_for;
-    use crate::find::matchers::Matcher;
     use crate::find::tests::fix_up_slashes;
     use crate::find::tests::FakeDependencies;
 
@@ -950,36 +947,31 @@ mod tests {
             if let Err(e) = symlink("abbbc", "test_data/links/link-f") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
             if let Err(e) = symlink("subdir", "test_data/links/link-d") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
             if let Err(e) = symlink("missing", "test_data/links/link-missing") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
             if let Err(e) = symlink("abbbc/x", "test_data/links/link-notdir") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
             if let Err(e) = symlink("link-loop", "test_data/links/link-loop") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
         }
@@ -1060,8 +1052,9 @@ mod tests {
         File::create(&file_path).expect("create temp file");
 
         let mtime = chrono::Local
-            .ymd(2000, 01, 15)
-            .and_hms_nano(09, 30, 21, 2000000);
+            .with_ymd_and_hms(2000, 1, 15, 9, 30, 21)
+            .unwrap()
+            + Duration::nanoseconds(2_000_000);
         filetime::set_file_mtime(
             &file_path,
             filetime::FileTime::from_unix_time(mtime.timestamp(), mtime.timestamp_subsec_nanos()),
@@ -1102,7 +1095,7 @@ mod tests {
         let matcher = Printf::new("%u %U %g %G").unwrap();
         assert!(matcher.matches(&file_info, &mut deps.new_matcher_io()));
         assert_eq!(
-            format!("{} {} {} {}", user, uid, group, gid),
+            format!("{user} {uid} {group} {gid}"),
             deps.get_output_as_string()
         );
     }
