@@ -32,14 +32,12 @@ impl TypeMatcher {
             // D: door (Solaris)
             "D" => {
                 return Err(From::from(format!(
-                    "Type argument {} not supported yet",
-                    type_string
+                    "Type argument {type_string} not supported yet"
                 )))
             }
             _ => {
                 return Err(From::from(format!(
-                    "Unrecognised type argument {}",
-                    type_string
+                    "Unrecognised type argument {type_string}"
                 )))
             }
         };
@@ -71,7 +69,6 @@ impl Matcher for TypeMatcher {
 mod tests {
     use super::*;
     use crate::find::matchers::tests::get_dir_entry_for;
-    use crate::find::matchers::Matcher;
     use crate::find::tests::FakeDependencies;
     use std::io::ErrorKind;
 
@@ -112,15 +109,13 @@ mod tests {
             if let Err(e) = symlink("abbbc", "test_data/links/link-f") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
             if let Err(e) = symlink("subdir", "test_data/links/link-d") {
                 assert!(
                     e.kind() == ErrorKind::AlreadyExists,
-                    "Failed to create sym link: {:?}",
-                    e
+                    "Failed to create sym link: {e:?}"
                 );
             }
         };
@@ -163,7 +158,7 @@ mod tests {
         let deps = FakeDependencies::new();
 
         for typ in &["b", "c", "p", "s"] {
-            let matcher = TypeMatcher::new(typ.as_ref()).unwrap();
+            let matcher = TypeMatcher::new(typ).unwrap();
             assert!(!matcher.matches(&dir, &mut deps.new_matcher_io()));
             assert!(!matcher.matches(&file, &mut deps.new_matcher_io()));
         }
