@@ -29,7 +29,7 @@ impl Default for Config {
             same_file_system: false,
             depth_first: false,
             min_depth: 0,
-            max_depth: usize::max_value(),
+            max_depth: usize::MAX,
             sorted_output: false,
             help_requested: false,
             version_requested: false,
@@ -51,6 +51,7 @@ pub struct StandardDependencies {
 }
 
 impl StandardDependencies {
+    #[must_use]
     pub fn new() -> Self {
         Self {
             output: Rc::new(RefCell::new(stdout())),
@@ -149,7 +150,10 @@ fn process_dir<'a>(
     let mut it = walkdir.into_iter();
     while let Some(result) = it.next() {
         match result {
-            Err(err) => writeln!(&mut stderr(), "Error: {}: {}", dir, err).unwrap(),
+            Err(err) => {
+                uucore::error::set_exit_code(1);
+                writeln!(&mut stderr(), "Error: {dir}: {err}").unwrap()
+            }
             Ok(entry) => {
                 let mut matcher_io = matchers::MatcherIO::new(deps);
                 if matcher.matches(&entry, &mut matcher_io) {
@@ -253,9 +257,9 @@ fn print_version() {
 /// the name of the executable.
 pub fn find_main<'a>(args: &[&str], deps: &'a dyn Dependencies<'a>) -> i32 {
     match do_find(&args[1..], deps) {
-        Ok(_) => 0,
+        Ok(_) => uucore::error::get_exit_code(),
         Err(e) => {
-            writeln!(&mut stderr(), "Error: {}", e).unwrap();
+            writeln!(&mut stderr(), "Error: {e}").unwrap();
             1
         }
     }
@@ -264,18 +268,16 @@ pub fn find_main<'a>(args: &[&str], deps: &'a dyn Dependencies<'a>) -> i32 {
 #[cfg(test)]
 mod tests {
 
-    use std::cell::RefCell;
     use std::fs;
-    use std::io::{Cursor, ErrorKind, Read, Write};
-    use std::time::{Duration, SystemTime};
-    use std::vec::Vec;
+    use std::io::{Cursor, ErrorKind, Read};
+    use std::time::Duration;
     use tempfile::Builder;
 
     #[cfg(unix)]
     use std::os::unix::fs::symlink;
 
     #[cfg(windows)]
-    use std::os::windows::fs::{symlink_dir, symlink_file};
+    use std::os::windows::fs::symlink_file;
 
     use crate::find::matchers::MatcherIO;
 
@@ -340,8 +342,7 @@ mod tests {
         if let Err(e) = symlink("abbbc", "test_data/links/link-f") {
             assert!(
                 e.kind() == ErrorKind::AlreadyExists,
-                "Failed to create sym link: {:?}",
-                e
+                "Failed to create sym link: {e:?}"
             );
         }
         #[cfg(windows)]
@@ -694,7 +695,7 @@ mod tests {
         }
     }
 
-    /// Helper function for the find_ctime/find_atime/find_mtime tests.
+    /// Helper function for the `find_ctime/find_atime/find_mtime` tests.
     fn file_time_helper(file_time: SystemTime, arg: &str) {
         // check file time matches a file that's old enough
         {
@@ -735,6 +736,31 @@ mod tests {
         }
     }
 
+    // Because the time when files exist locally is different
+    // from the time when Github Actions pulls them,
+    // it is difficult to write tests that limit a certain time period.
+    //
+    // For example, a Github Action may pull files from a new git commit within a few minutes,
+    // causing the file time to be refreshed to the pull time.
+    // and The files on the local branch may be several days old.
+    //
+    // So this test may not be too accurate and can only ensure that
+    // the function can be correctly identified.
+    #[test]
+    fn find_amin_cmin_mmin() {
+        let args = ["-amin", "-cmin", "-mmin"];
+        let times = ["-60", "-120", "-240", "+60", "+120", "+240"];
+
+        for arg in args {
+            for time in times {
+                let deps = FakeDependencies::new();
+                let rc = find_main(&["find", "./test_data/simple/subdir", arg, time], &deps);
+
+                assert_eq!(rc, 0);
+            }
+        }
+    }
+
     #[test]
     fn find_size() {
         let deps = FakeDependencies::new();
@@ -856,4 +882,341 @@ mod tests {
             fix_up_slashes("./test_data/simple\n"),
         );
     }
+
+    #[test]
+    fn test_find_newer_xy_all_args() {
+        // 1. The t parameter is not allowed at the X position.
+        // 2. Current Linux filesystem do not support Birthed Time queries,
+        //    so the B parameter will be excluded in linux.
+        #[cfg(target_os = "linux")]
+        let x_options = ["a", "c", "m"];
+        #[cfg(not(target_os = "linux"))]
+        let x_options = ["a", "B", "c", "m"];
+        #[cfg(target_os = "linux")]
+        let y_options = ["a", "c", "m"];
+        #[cfg(not(target_os = "linux"))]
+        let y_options = ["a", "B", "c", "m"];
+
+        for &x in x_options.iter() {
+            for &y in &y_options {
+                let arg = &format!("-newer{x}{y}").to_string();
+                let deps = FakeDependencies::new();
+                let rc = find_main(
+                    &[
+                        "find",
+                        "./test_data/simple/subdir",
+                        arg,
+                        "./test_data/simple/subdir/ABBBC",
+                    ],
+                    &deps,
+                );
+
+                assert_eq!(rc, 0);
+            }
+        }
+    }
+
+    #[test]
+    #[cfg(target_os = "linux")]
+    fn test_find_newer_xy_have_not_birthed_time_filesystem() {
+        let y_options = ["a", "c", "m"];
+        for &y in &y_options {
+            let arg = &format!("-newerB{y}").to_string();
+            let deps = FakeDependencies::new();
+            let rc = find_main(
+                &[
+                    "find",
+                    "./test_data/simple/subdir",
+                    arg,
+                    "./test_data/simple/subdir/ABBBC",
+                ],
+                &deps,
+            );
+
+            assert_eq!(rc, 1);
+        }
+    }
+
+    #[test]
+    fn test_find_newer_xy_before_created_time() {
+        // normal - before the created time
+        #[cfg(target_os = "linux")]
+        let args = ["-newerat", "-newerct", "-newermt"];
+        #[cfg(not(target_os = "linux"))]
+        let args = ["-newerat", "-newerBt", "-newerct", "-newermt"];
+        let times = ["jan 01, 2000", "jan 01, 2000 00:00:00"];
+
+        for arg in args {
+            for time in times {
+                let deps = FakeDependencies::new();
+                let rc = find_main(&["find", "./test_data/simple/subdir", arg, time], &deps);
+
+                assert_eq!(rc, 0);
+                assert!(deps
+                    .get_output_as_string()
+                    .contains("./test_data/simple/subdir"));
+                assert!(deps.get_output_as_string().contains("ABBBC"));
+            }
+        }
+    }
+
+    #[test]
+    fn test_find_newer_xy_after_created_time() {
+        // normal - after the created time
+        #[cfg(target_os = "linux")]
+        let args = ["-newerat", "-newerct", "-newermt"];
+        #[cfg(not(target_os = "linux"))]
+        let args = ["-newerat", "-newerBt", "-newerct", "-newermt"];
+        let times = ["jan 01, 2037", "jan 01, 2037 00:00:00"];
+
+        for arg in args {
+            for time in times {
+                let deps = FakeDependencies::new();
+                let rc = find_main(&["find", "./test_data/simple/subdir", arg, time], &deps);
+
+                assert_eq!(rc, 0);
+                assert_eq!(deps.get_output_as_string(), "");
+            }
+        }
+    }
+
+    #[test]
+    fn test_find_newer_xy_empty_time_parameter() {
+        // When an empty time parameter is passed in,
+        // the program will use 00:00 of the current day as the default time.
+        // Therefore, the files checkout of the git repository while
+        // this test was running are likely to be newer than the default time.
+        #[cfg(target_os = "linux")]
+        let args = ["-newerat", "-newerct", "-newermt"];
+        #[cfg(not(target_os = "linux"))]
+        let args = ["-newerat", "-newerBt", "-newerct", "-newermt"];
+        let time = "";
+
+        for &arg in &args {
+            let deps = FakeDependencies::new();
+            let rc = find_main(&["find", "./test_data/simple/subdir", arg, time], &deps);
+
+            assert_eq!(rc, 0);
+            // Output comparison has been temporarily removed to account for the possibility that
+            // migration out of the repository started before 00:00 and testing was completed after 00:00.
+        }
+    }
+
+    #[test]
+    fn test_find_newer_xy_error_time() {
+        // Catch a parsing error.
+        #[cfg(target_os = "linux")]
+        let args = ["-newerat", "-newerct", "-newermt"];
+        #[cfg(not(target_os = "linux"))]
+        let args = ["-newerat", "-newerBt", "-newerct", "-newermt"];
+        let time = "2037, jan 01";
+
+        for &arg in &args {
+            let deps = FakeDependencies::new();
+            let rc = find_main(&["find", "./test_data/simple/subdir", arg, time], &deps);
+
+            assert_eq!(rc, 1);
+        }
+    }
+
+    #[test]
+    #[cfg(target_os = "linux")]
+    fn test_no_permission_file_error() {
+        use std::{path::Path, process::Command};
+
+        let path = Path::new("./test_data/no_permission");
+        let _result = fs::create_dir(path);
+        // Generate files without permissions.
+        // std::fs cannot change file permissions to 000 in normal user state,
+        // so use chmod via Command to change permissions.
+        let _output = Command::new("chmod")
+            .arg("-rwx")
+            .arg("./test_data/no_permission")
+            .output()
+            .expect("cannot set file permission");
+
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/no_permission"], &deps);
+
+        assert_eq!(rc, 1);
+
+        // Reset the exit code global variable in case we run another test after this one
+        // See https://github.com/uutils/coreutils/issues/5777
+        uucore::error::set_exit_code(0);
+
+        if path.exists() {
+            let _result = fs::create_dir(path);
+            // Remove the unreadable and writable status of the file to avoid affecting other tests.
+            let _output = Command::new("chmod")
+                .arg("+rwx")
+                .arg("./test_data/no_permission")
+                .output()
+                .expect("cannot set file permission");
+        }
+    }
+
+    #[test]
+    #[cfg(target_os = "linux")]
+    fn test_user_predicate() {
+        use std::{os::unix::fs::MetadataExt, path::Path};
+
+        use nix::unistd::{Uid, User};
+
+        let path = Path::new("./test_data/simple/subdir");
+        let uid = path.metadata().unwrap().uid();
+        let user = User::from_uid(Uid::from_raw(uid)).unwrap().unwrap().name;
+
+        let deps = FakeDependencies::new();
+        let rc = find_main(
+            &["find", "./test_data/simple/subdir", "-user", &user],
+            &deps,
+        );
+
+        assert_eq!(rc, 0);
+        assert_eq!(
+            deps.get_output_as_string(),
+            "./test_data/simple/subdir\n./test_data/simple/subdir/ABBBC\n"
+        );
+
+        // test uid
+        let deps = FakeDependencies::new();
+        let rc = find_main(
+            &[
+                "find",
+                "./test_data/simple/subdir",
+                "-uid",
+                &uid.to_string(),
+            ],
+            &deps,
+        );
+        assert_eq!(rc, 0);
+
+        // test empty uid
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/simple/subdir", "-uid", ""], &deps);
+        assert_eq!(rc, 1);
+
+        // test not a number
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/simple/subdir", "-uid", "a"], &deps);
+        assert_eq!(rc, 1);
+
+        // test empty user name
+        ["-user", "-nouser"].iter().for_each(|&arg| {
+            let deps = FakeDependencies::new();
+            let rc = find_main(&["find", "./test_data/simple/subdir", arg, ""], &deps);
+
+            assert_eq!(rc, 1);
+
+            let deps = FakeDependencies::new();
+            let rc = find_main(&["find", "./test_data/simple/subdir", arg, " "], &deps);
+
+            assert_eq!(rc, 1);
+        });
+    }
+
+    #[test]
+    #[cfg(target_os = "linux")]
+    fn test_nouser_predicate() {
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/simple/subdir", "-nouser"], &deps);
+
+        assert_eq!(rc, 0);
+        assert_eq!(deps.get_output_as_string(), "");
+    }
+
+    #[test]
+    #[cfg(target_os = "linux")]
+    fn test_group_predicate() {
+        use std::{os::unix::fs::MetadataExt, path::Path};
+
+        use nix::unistd::{Gid, Group};
+
+        let path = Path::new("./test_data/simple/subdir");
+        let gid = path.metadata().unwrap().gid();
+        let group = Group::from_gid(Gid::from_raw(gid)).unwrap().unwrap().name;
+
+        let deps = FakeDependencies::new();
+        let rc = find_main(
+            &["find", "./test_data/simple/subdir", "-group", &group],
+            &deps,
+        );
+
+        assert_eq!(rc, 0);
+        assert_eq!(
+            deps.get_output_as_string(),
+            "./test_data/simple/subdir\n./test_data/simple/subdir/ABBBC\n"
+        );
+
+        // test gid
+        let deps = FakeDependencies::new();
+        let rc = find_main(
+            &[
+                "find",
+                "./test_data/simple/subdir",
+                "-gid",
+                gid.to_string().as_str(),
+            ],
+            &deps,
+        );
+        assert_eq!(rc, 0);
+
+        // test empty gid
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/simple/subdir", "-gid", ""], &deps);
+        assert_eq!(rc, 1);
+
+        // test not a number
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/simple/subdir", "-gid", "a"], &deps);
+        assert_eq!(rc, 1);
+
+        // test empty user name and group name
+        ["-group", "-nogroup"].iter().for_each(|&arg| {
+            let deps = FakeDependencies::new();
+            let rc = find_main(&["find", "./test_data/simple/subdir", arg, ""], &deps);
+
+            assert_eq!(rc, 1);
+
+            let deps = FakeDependencies::new();
+            let rc = find_main(&["find", "./test_data/simple/subdir", arg, " "], &deps);
+
+            assert_eq!(rc, 1);
+        });
+    }
+
+    #[test]
+    #[cfg(target_os = "linux")]
+    fn test_nogroup_predicate() {
+        let deps = FakeDependencies::new();
+        let rc = find_main(&["find", "./test_data/simple/subdir", "-nogroup"], &deps);
+
+        assert_eq!(rc, 0);
+        assert_eq!(deps.get_output_as_string(), "");
+    }
+
+    #[test]
+    #[cfg(unix)]
+    fn test_fs_matcher() {
+        use crate::find::tests::FakeDependencies;
+        use matchers::fs::get_file_system_type;
+        use std::path::Path;
+
+        let path = Path::new("./test_data/simple/subdir");
+        let target_fs_type = get_file_system_type(path).unwrap();
+
+        // should match fs type
+        let deps = FakeDependencies::new();
+        let rc = find_main(
+            &[
+                "find",
+                "./test_data/simple/subdir",
+                "-fstype",
+                &target_fs_type,
+            ],
+            &deps,
+        );
+
+        assert_eq!(rc, 0);
+    }
 }
